# -*- coding: utf-8 -*-
##----------------------------------------------------------------------
## reportsummary Test
##----------------------------------------------------------------------
## Copyright (C) 2007-2009 The NOC Project
## See LICENSE for details
##----------------------------------------------------------------------
from noc.lib.test import ReportApplicationTestCase

class reportsummaryTestCase(ReportApplicationTestCase):
    posts=[{"vrf":1,"prefix":"0.0.0.0/0","afi":"4"}]